@@ -15,7 +15,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 
-$VERSION = '1.08';
+$VERSION = '1.11';
 
 sub WritePhaseOne($$$);
 sub ProcessPhaseOne($$$);
@@ -71,6 +71,7 @@ my @formatName = ( undef, 'string', 'int16s', undef, 'int32s' );
         # >2 = compressed
         # 5 = non-linear
         PrintConv => { #PH
+            0 => 'Uncompressed', #https://github.com/darktable-org/darktable/issues/7308
             1 => 'RAW 1', #? (encrypted)
             2 => 'RAW 2', #? (encrypted)
             3 => 'IIQ L', # (now "L14", ref IB)
@@ -153,7 +154,7 @@ my @formatName = ( undef, 'string', 'int16s', undef, 'int32s' );
         Format => 'int16s',
         Count => -1,
         Flags => ['Unknown','Hidden'],
-        PrintConv => 'length($val) > 60 ? substr($val,0,55) . "[...]" : $val',
+        PrintConv => \&Image::ExifTool::LimitLongValues,
     },
     0x0226 => {
         Name => 'ColorMatrix2',
@@ -184,13 +185,13 @@ my @formatName = ( undef, 'string', 'int16s', undef, 'int32s' );
         Name => 'PhaseOne_0x0258',
         Format => 'int16s',
         Flags => ['Unknown','Hidden'],
-        PrintConv => 'length($val) > 60 ? substr($val,0,55) . "[...]" : $val',
+        PrintConv => \&Image::ExifTool::LimitLongValues,
     },
     0x025a => { #PH
         Name => 'PhaseOne_0x025a',
         Format => 'int16s',
         Flags => ['Unknown','Hidden'],
-        PrintConv => 'length($val) > 60 ? substr($val,0,55) . "[...]" : $val',
+        PrintConv => \&Image::ExifTool::LimitLongValues,
     },
     # 0x0300 - int32u: 100,101,102
     0x0301 => { Name => 'FirmwareVersions', Format => 'string' },
@@ -449,7 +450,7 @@ sub WritePhaseOne($$$)
 
     return undef if $dirLen < 12;
     unless ($$tagTablePtr{VARS} and $$tagTablePtr{VARS}{ENTRY_SIZE}) {
-        $et->WarnOnce("No ENTRY_SIZE for $$tagTablePtr{TABLE_NAME}");
+        $et->Warn("No ENTRY_SIZE for $$tagTablePtr{TABLE_NAME}");
         return undef;
     }
     my $entrySize = $$tagTablePtr{VARS}{ENTRY_SIZE};
@@ -473,7 +474,7 @@ sub WritePhaseOne($$$)
     return undef if $numEntries < 2 or $numEntries > 300 or $ifdEnd > $dirLen;
     my $hdrBuff = $hdr;
     my $valBuff = '';   # buffer for value data
-    my $fixup = new Image::ExifTool::Fixup;
+    my $fixup = Image::ExifTool::Fixup->new;
     my $index;
     for ($index=0; $index<$numEntries; ++$index) {
         my $entry = $dirStart + $ifdStart + 8 + $entrySize * $index;
@@ -585,12 +586,12 @@ sub ProcessPhaseOne($$$)
     my $dirLen = $$dirInfo{DirLen} || $$dirInfo{DataLen} - $dirStart;
     my $binary = $et->Options('Binary');
     my $verbose = $et->Options('Verbose');
-    my $md5 = $$et{ImageDataMD5};
+    my $hash = $$et{ImageDataHash};
     my $htmlDump = $$et{HTML_DUMP};
 
     return 0 if $dirLen < 12;
     unless ($$tagTablePtr{VARS} and $$tagTablePtr{VARS}{ENTRY_SIZE}) {
-        $et->WarnOnce("No ENTRY_SIZE for $$tagTablePtr{TABLE_NAME}");
+        $et->Warn("No ENTRY_SIZE for $$tagTablePtr{TABLE_NAME}");
         return undef;
     }
     my $entrySize = $$tagTablePtr{VARS}{ENTRY_SIZE};
@@ -631,7 +632,7 @@ sub ProcessPhaseOne($$$)
             $formatSize = Get32u($dataPt, $entry+4);
             $formatStr = $formatName[$formatSize];
             unless ($formatStr) {
-                $et->WarnOnce("Unrecognized $ifdType format size $formatSize",1);
+                $et->Warn("Unrecognized $ifdType format size $formatSize",1);
                 $formatSize = 1;
                 $formatStr = 'undef';
             }
@@ -678,16 +679,16 @@ sub ProcessPhaseOne($$$)
                 }
             }
         }
-        if ($md5 and $tagInfo and $$tagInfo{IsImageData}) {
+        if ($hash and $tagInfo and $$tagInfo{IsImageData}) {
             my ($pos, $len) = ($valuePtr, $size);
             while ($len) {
                 my $n = $len > 65536 ? 65536 : $len;
                 my $tmp = substr($$dataPt, $pos, $n);
-                $md5->add($tmp);
+                $hash->add($tmp);
                 $len -= $n;
                 $pos += $n;
             }
-            $et->VPrint(0, "$$et{INDENT}(ImageDataMD5: $size bytes of PhaseOne:$$tagInfo{Name})\n");
+            $et->VPrint(0, "$$et{INDENT}(ImageDataHash: $size bytes of PhaseOne:$$tagInfo{Name})\n");
         }
         my %parms = (
             DirName => $ifdType,
@@ -725,7 +726,7 @@ One maker notes.
 
 =head1 AUTHOR
 
-Copyright 2003-2023, Phil Harvey (philharvey66 at gmail.com)
+Copyright 2003-2024, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
